@@ -77,12 +77,7 @@ Smb4KAuthOptionsPage::Smb4KAuthOptionsPage( QWidget *parent ) : KTabWidget( pare
                              password_box );
   use_wallet->setObjectName( "kcfg_UseWallet" );
 
-  QCheckBox *remember_pass = new QCheckBox( Smb4KSettings::self()->rememberLoginsItem()->label(),
-                             password_box );
-  remember_pass->setObjectName( "kcfg_RememberLogins" );
-
   pass_layout->addWidget( use_wallet, 0, 0, 0 );
-  pass_layout->addWidget( remember_pass, 1, 0, 0 );
 
   // Default login box
   QGroupBox *default_box   = new QGroupBox( i18n( "Default Login" ), general_tab );
@@ -265,7 +260,7 @@ void Smb4KAuthOptionsPage::displayWalletEntries()
   {
     switch ( m_entries_list.at( i )->type() )
     {
-      case Smb4KAuthInfo::Default:
+      case Unknown:
       {
         (void) new QListWidgetItem( KIcon( "dialog-password" ), i18n( "Default Login" ), m_entries_widget );
         break;
@@ -355,8 +350,8 @@ void Smb4KAuthOptionsPage::showDetails( Smb4KAuthInfo *authInfo )
   
   switch ( authInfo->type() )
   {
-    case Smb4KAuthInfo::Host:
-    case Smb4KAuthInfo::Share:
+    case Host:
+    case Share:
     {
       m_details_widget->setColumnCount( 2 );
       m_details_widget->setRowCount( 4 );
@@ -386,13 +381,13 @@ void Smb4KAuthOptionsPage::showDetails( Smb4KAuthInfo *authInfo )
       m_details_widget->setItem( 1, 0, workgroup_label );
       m_details_widget->setItem( 1, 1, new QTableWidgetItem( authInfo->workgroupName() ) );
       m_details_widget->setItem( 2, 0, login_label );
-      m_details_widget->setItem( 2, 1, new QTableWidgetItem( authInfo->login() ) );
+      m_details_widget->setItem( 2, 1, new QTableWidgetItem( authInfo->userName() ) );
       m_details_widget->setItem( 3, 0, password_label );
       m_details_widget->setItem( 3, 1, new QTableWidgetItem( authInfo->password() ) );
           
       break;
     }
-    case Smb4KAuthInfo::Default:
+    default:
     {
       m_details_widget->setColumnCount( 2 );
       m_details_widget->setRowCount( 3 );
@@ -416,16 +411,12 @@ void Smb4KAuthOptionsPage::showDetails( Smb4KAuthInfo *authInfo )
       m_details_widget->setItem( 0, 0, entry_label );
       m_details_widget->setItem( 0, 1, entry );
       m_details_widget->setItem( 1, 0, login_label );
-      m_details_widget->setItem( 1, 1, new QTableWidgetItem( authInfo->login() ) );
+      m_details_widget->setItem( 1, 1, new QTableWidgetItem( authInfo->userName() ) );
       m_details_widget->setItem( 2, 0, password_label );
       m_details_widget->setItem( 2, 1, new QTableWidgetItem( authInfo->password() ) );
           
       break;
     }
-    default:
-    {
-      break;
-    }
   }
 
   m_auth_info = authInfo;
@@ -486,7 +477,7 @@ void Smb4KAuthOptionsPage::slotDetailsClicked( bool checked )
     {
       if ( QString::compare( selected_items.first()->text(), m_entries_list.at( i )->unc() ) == 0 ||
            (QString::compare( selected_items.first()->text(), i18n( "Default Login" ) ) == 0 &&
-            m_entries_list.at( i )->type() == Smb4KAuthInfo::Default) )
+            m_entries_list.at( i )->type() == Unknown) )
       {
         showDetails( m_entries_list.at( i ) );
         break;
@@ -522,12 +513,12 @@ void Smb4KAuthOptionsPage::slotDetailsChanged( int row, int column )
     {
       if ( QString::compare( m_details_widget->item( 0, 1 )->text(), m_entries_list.at( i )->unc() ) == 0 ||
            (QString::compare( m_details_widget->item( 0, 1 )->text(), i18n( "Default Login" ) ) == 0 &&
-           m_entries_list.at( i )->type() == Smb4KAuthInfo::Default) )
+           m_entries_list.at( i )->type() == Unknown) )
       {
         switch ( m_entries_list.at( i )->type() )
         {
-          case Smb4KAuthInfo::Host:
-          case Smb4KAuthInfo::Share:
+          case Host:
+          case Share:
           {
             if ( column == 1 )
             {
@@ -540,7 +531,7 @@ void Smb4KAuthOptionsPage::slotDetailsChanged( int row, int column )
                 }
                 case 2: // Login
                 {
-                  m_entries_list[i]->setLogin( m_details_widget->item( row, column )->text() );
+                  m_entries_list[i]->setUserName( m_details_widget->item( row, column )->text() );
                   break;
                 }
                 case 3: // Password
@@ -561,7 +552,7 @@ void Smb4KAuthOptionsPage::slotDetailsChanged( int row, int column )
             
             break;
           }
-          case Smb4KAuthInfo::Default:
+          default:
           {
             if ( column == 1 )
             {
@@ -569,7 +560,7 @@ void Smb4KAuthOptionsPage::slotDetailsChanged( int row, int column )
               {
                 case 1: // Login
                 {
-                  m_entries_list[i]->setLogin( m_details_widget->item( row, column )->text() );
+                  m_entries_list[i]->setUserName( m_details_widget->item( row, column )->text() );
                   break;
                 }
                 case 2: // Password
@@ -590,10 +581,6 @@ void Smb4KAuthOptionsPage::slotDetailsChanged( int row, int column )
             
             break;
           }
-          default:
-          {
-            break;
-          }
         }
         
         break;
@@ -643,11 +630,11 @@ void Smb4KAuthOptionsPage::slotRemoveActionTriggered( bool /*checked*/ )
   {
     if ( QString::compare( m_entries_widget->currentItem()->text(), m_entries_list.at( i )->unc() ) == 0 ||
          (QString::compare( m_entries_widget->currentItem()->text(), i18n( "Default Login" ) ) == 0 &&
-         m_entries_list.at( i )->type() == Smb4KAuthInfo::Default) )
+         m_entries_list.at( i )->type() == Unknown) )
     {
       switch ( m_entries_list.at( i )->type() )
       {
-        case Smb4KAuthInfo::Default:
+        case Unknown:
         {
           QCheckBox *default_login = findChild<QCheckBox *>( "kcfg_UseDefaultLogin" );
           m_default_login = default_login->isChecked();
@@ -736,26 +723,22 @@ void Smb4KAuthOptionsPage::slotUndoDetailsActionTriggered( bool /*checked*/ )
   for ( int i = 0; i < m_entries_list.size(); ++i )
   {
     if ( QString::compare( m_auth_info->unc(), m_entries_list.at( i )->unc() ) == 0 ||
-         (m_auth_info->type() == Smb4KAuthInfo::Default && m_auth_info->type() == m_entries_list.at( i )->type()) )
+         (m_auth_info->type() == Unknown && m_auth_info->type() == m_entries_list.at( i )->type()) )
     {
       switch ( m_auth_info->type() )
       {
-        case Smb4KAuthInfo::Host:
-        case Smb4KAuthInfo::Share:
+        case Host:
+        case Share:
         {
           m_entries_list[i]->setWorkgroupName( m_auth_info->workgroupName() );
-          m_entries_list[i]->setLogin( m_auth_info->login() );
-          m_entries_list[i]->setPassword( m_auth_info->password() );
-          break;
-        }
-        case Smb4KAuthInfo::Default:
-        {
-          m_entries_list[i]->setLogin( m_auth_info->login() );
+          m_entries_list[i]->setUserName( m_auth_info->userName() );
           m_entries_list[i]->setPassword( m_auth_info->password() );
           break;
         }
         default:
         {
+          m_entries_list[i]->setUserName( m_auth_info->userName() );
+          m_entries_list[i]->setPassword( m_auth_info->password() );
           break;
         }
       }
